@@ -1,6 +1,6 @@
 expcomp <- function(object, ...)
 { 	 		
-  fList <- list(b3, b4, b5, b6, b7, l3, l4, l5, l6, l7)
+  fList <- list(b4, b5, b6, b7, l4, l5, l6, l7)
 	fnList <- lapply(fList, function(x) x$name)
   print("Fitting all sigmoidal models...")
   flush.console()
