@@ -10,13 +10,13 @@ verbose = TRUE,
 ...)
 {
     ## create dummy "pcrbatch" data
-    DAT <- matrix(nrow = 40, ncol = length(group) + 1)
-    colnames(DAT) <- paste("Run", 1:ncol(DAT), sep = ".")
-    colnames(DAT)[1] <- "Vars"
-    DAT <- data.frame(DAT)
-    class(DAT)[2] <- "pcrbatch"
-    
-    ratiobatch(data = DAT, group = group, which.eff = effVec, which.cp = cpVec,
+    DATA <- rbind(effVec, cpVec)
+    colnames(DATA) <- group
+    DATA <- as.data.frame(DATA)
+    DATA <- cbind(Vars = c("ext.eff", "sig.ext"), DATA)
+    class(DATA)[2] <- "pcrbatch"       
+      
+    ratiobatch(data = DATA, group = group, which.eff = "ext", which.cp = "ext",
                type.eff = type.eff, plot = plot, combs = combs, refmean = refmean,
                verbose = verbose, ...)
 }
\ No newline at end of file
